@@ -149,10 +149,14 @@ class PsiStatistics(Statistics):
         for x in range(len(self.environment.grid)):
             for y in range(len(self.environment.grid[x])):
                 for z in range(len(self.environment.grid[x][y])):
-                    f.write(' '.join(map(str, self._get_entry(x, y, z, step))) + '\n')
+                    entry = self._get_entry(x, y, z, step)
+                    if entry:
+                        f.write(' '.join(map(str, self._get_entry(x, y, z, step))) + '\n')
 
     def _get_entry(self, x, y, z, step):
         cell = self.environment.grid[x][y][z]
+        if cell.is_empty() and cell.algae == 0:
+            return None
         return map(float, [x, y, z] + [0 if cell.is_empty() else cell.foram.chambers,
                                        0 if cell.is_empty() else cell.foram.energy,
                                        cell.algae,
